@@ -1,13 +1,15 @@
 """
-Main interface for signer service client
+Type annotations for signer service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
     ```python
     import boto3
-    from mypy_boto3_signer import SignerClient
+    from mypy_boto3_signer import signerClient
 
-    client: SignerClient = boto3.client("signer")
+    client: signerClient = boto3.client("signer")
     ```
 """
 import sys
@@ -16,12 +18,13 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_signer.paginator import (
+from .literals import SigningProfileStatusType, SigningStatusType
+from .paginator import (
     ListSigningJobsPaginator,
     ListSigningPlatformsPaginator,
     ListSigningProfilesPaginator,
 )
-from mypy_boto3_signer.type_defs import (
+from .type_defs import (
     AddProfilePermissionResponseTypeDef,
     DescribeSigningJobResponseTypeDef,
     DestinationTypeDef,
@@ -40,7 +43,7 @@ from mypy_boto3_signer.type_defs import (
     SourceTypeDef,
     StartSigningJobResponseTypeDef,
 )
-from mypy_boto3_signer.waiter import SuccessfulSigningJobWaiter
+from .waiter import SuccessfulSigningJobWaiter
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -48,7 +51,7 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("SignerClient",)
+__all__ = ("signerClient",)
 
 
 class BotocoreClientError(BaseException):
@@ -73,9 +76,10 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class SignerClient:
+class signerClient:
     """
-    [Signer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -91,22 +95,26 @@ class SignerClient:
         revisionId: str = None,
     ) -> AddProfilePermissionResponseTypeDef:
         """
-        [Client.add_profile_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.add_profile_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.add_profile_permission)
+        [Show boto3-stubs documentation](./client.md#add_profile_permission)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_signing_profile(self, profileName: str) -> None:
         """
-        [Client.cancel_signing_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.cancel_signing_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.cancel_signing_profile)
+        [Show boto3-stubs documentation](./client.md#cancel_signing_profile)
         """
 
     def describe_signing_job(self, jobId: str) -> DescribeSigningJobResponseTypeDef:
         """
-        [Client.describe_signing_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.describe_signing_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.describe_signing_job)
+        [Show boto3-stubs documentation](./client.md#describe_signing_job)
         """
 
     def generate_presigned_url(
@@ -117,31 +125,35 @@ class SignerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_signing_platform(self, platformId: str) -> GetSigningPlatformResponseTypeDef:
         """
-        [Client.get_signing_platform documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.get_signing_platform)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.get_signing_platform)
+        [Show boto3-stubs documentation](./client.md#get_signing_platform)
         """
 
     def get_signing_profile(
         self, profileName: str, profileOwner: str = None
     ) -> GetSigningProfileResponseTypeDef:
         """
-        [Client.get_signing_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.get_signing_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.get_signing_profile)
+        [Show boto3-stubs documentation](./client.md#get_signing_profile)
         """
 
     def list_profile_permissions(
         self, profileName: str, nextToken: str = None
     ) -> ListProfilePermissionsResponseTypeDef:
         """
-        [Client.list_profile_permissions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.list_profile_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.list_profile_permissions)
+        [Show boto3-stubs documentation](./client.md#list_profile_permissions)
         """
 
     def list_signing_jobs(
         self,
-        status: Literal["InProgress", "Failed", "Succeeded"] = None,
+        status: SigningStatusType = None,
         platformId: str = None,
         requestedBy: str = None,
         maxResults: int = None,
@@ -152,7 +164,8 @@ class SignerClient:
         jobInvoker: str = None,
     ) -> ListSigningJobsResponseTypeDef:
         """
-        [Client.list_signing_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.list_signing_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.list_signing_jobs)
+        [Show boto3-stubs documentation](./client.md#list_signing_jobs)
         """
 
     def list_signing_platforms(
@@ -164,7 +177,8 @@ class SignerClient:
         nextToken: str = None,
     ) -> ListSigningPlatformsResponseTypeDef:
         """
-        [Client.list_signing_platforms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.list_signing_platforms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.list_signing_platforms)
+        [Show boto3-stubs documentation](./client.md#list_signing_platforms)
         """
 
     def list_signing_profiles(
@@ -173,15 +187,17 @@ class SignerClient:
         maxResults: int = None,
         nextToken: str = None,
         platformId: str = None,
-        statuses: List[Literal["Active", "Canceled", "Revoked"]] = None,
+        statuses: List[SigningProfileStatusType] = None,
     ) -> ListSigningProfilesResponseTypeDef:
         """
-        [Client.list_signing_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.list_signing_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.list_signing_profiles)
+        [Show boto3-stubs documentation](./client.md#list_signing_profiles)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def put_signing_profile(
@@ -195,26 +211,30 @@ class SignerClient:
         tags: Dict[str, str] = None,
     ) -> PutSigningProfileResponseTypeDef:
         """
-        [Client.put_signing_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.put_signing_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.put_signing_profile)
+        [Show boto3-stubs documentation](./client.md#put_signing_profile)
         """
 
     def remove_profile_permission(
         self, profileName: str, revisionId: str, statementId: str
     ) -> RemoveProfilePermissionResponseTypeDef:
         """
-        [Client.remove_profile_permission documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.remove_profile_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.remove_profile_permission)
+        [Show boto3-stubs documentation](./client.md#remove_profile_permission)
         """
 
     def revoke_signature(self, jobId: str, reason: str, jobOwner: str = None) -> None:
         """
-        [Client.revoke_signature documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.revoke_signature)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.revoke_signature)
+        [Show boto3-stubs documentation](./client.md#revoke_signature)
         """
 
     def revoke_signing_profile(
         self, profileName: str, profileVersion: str, reason: str, effectiveTime: datetime
     ) -> None:
         """
-        [Client.revoke_signing_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.revoke_signing_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.revoke_signing_profile)
+        [Show boto3-stubs documentation](./client.md#revoke_signing_profile)
         """
 
     def start_signing_job(
@@ -226,17 +246,20 @@ class SignerClient:
         profileOwner: str = None,
     ) -> StartSigningJobResponseTypeDef:
         """
-        [Client.start_signing_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.start_signing_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.start_signing_job)
+        [Show boto3-stubs documentation](./client.md#start_signing_job)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     @overload
@@ -244,7 +267,7 @@ class SignerClient:
         self, operation_name: Literal["list_signing_jobs"]
     ) -> ListSigningJobsPaginator:
         """
-        [Paginator.ListSigningJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningJobs)[Show boto3-stubs documentation](./paginators.md#listsigningjobspaginator)
         """
 
     @overload
@@ -252,7 +275,7 @@ class SignerClient:
         self, operation_name: Literal["list_signing_platforms"]
     ) -> ListSigningPlatformsPaginator:
         """
-        [Paginator.ListSigningPlatforms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningPlatforms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningPlatforms)[Show boto3-stubs documentation](./paginators.md#listsigningplatformspaginator)
         """
 
     @overload
@@ -260,12 +283,12 @@ class SignerClient:
         self, operation_name: Literal["list_signing_profiles"]
     ) -> ListSigningProfilesPaginator:
         """
-        [Paginator.ListSigningProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningProfiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningProfiles)[Show boto3-stubs documentation](./paginators.md#listsigningprofilespaginator)
         """
 
     def get_waiter(
         self, waiter_name: Literal["successful_signing_job"]
     ) -> SuccessfulSigningJobWaiter:
         """
-        [Waiter.SuccessfulSigningJob documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Waiter.SuccessfulSigningJob)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Waiter.successful_signing_job)[Show boto3-stubs documentation](./waiters.md#successfulsigningjobwaiter)
         """
