@@ -1,44 +1,40 @@
 """
-Main interface for signer service client paginators.
+Type annotations for signer service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
     ```python
     import boto3
 
-    from mypy_boto3_signer import SignerClient
+    from mypy_boto3_signer import signerClient
     from mypy_boto3_signer.paginator import (
         ListSigningJobsPaginator,
         ListSigningPlatformsPaginator,
         ListSigningProfilesPaginator,
     )
 
-    client: SignerClient = boto3.client("signer")
+    client: signerClient = boto3.client("signer")
 
     list_signing_jobs_paginator: ListSigningJobsPaginator = client.get_paginator("list_signing_jobs")
     list_signing_platforms_paginator: ListSigningPlatformsPaginator = client.get_paginator("list_signing_platforms")
     list_signing_profiles_paginator: ListSigningProfilesPaginator = client.get_paginator("list_signing_profiles")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_signer.type_defs import (
+from .literals import SigningProfileStatusType, SigningStatusType
+from .type_defs import (
     ListSigningJobsResponseTypeDef,
     ListSigningPlatformsResponseTypeDef,
     ListSigningProfilesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "ListSigningJobsPaginator",
     "ListSigningPlatformsPaginator",
@@ -48,12 +44,12 @@ __all__ = (
 
 class ListSigningJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSigningJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningJobs)[Show boto3-stubs documentation](./paginators.md#listsigningjobspaginator)
     """
 
     def paginate(
         self,
-        status: Literal["InProgress", "Failed", "Succeeded"] = None,
+        status: SigningStatusType = None,
         platformId: str = None,
         requestedBy: str = None,
         isRevoked: bool = None,
@@ -63,13 +59,14 @@ class ListSigningJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSigningJobsResponseTypeDef]:
         """
-        [ListSigningJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningJobs.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listsigningjobspaginator)
         """
 
 
 class ListSigningPlatformsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSigningPlatforms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningPlatforms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningPlatforms)[Show boto3-stubs documentation](./paginators.md#listsigningplatformspaginator)
     """
 
     def paginate(
@@ -80,22 +77,24 @@ class ListSigningPlatformsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSigningPlatformsResponseTypeDef]:
         """
-        [ListSigningPlatforms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningPlatforms.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningPlatforms.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listsigningplatformspaginator)
         """
 
 
 class ListSigningProfilesPaginator(Boto3Paginator):
     """
-    [Paginator.ListSigningProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningProfiles)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningProfiles)[Show boto3-stubs documentation](./paginators.md#listsigningprofilespaginator)
     """
 
     def paginate(
         self,
         includeCanceled: bool = None,
         platformId: str = None,
-        statuses: List[Literal["Active", "Canceled", "Revoked"]] = None,
+        statuses: List[SigningProfileStatusType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSigningProfilesResponseTypeDef]:
         """
-        [ListSigningProfiles.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.45/reference/services/signer.html#Signer.Paginator.ListSigningProfiles.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/signer.html#signer.Paginator.ListSigningProfiles.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listsigningprofilespaginator)
         """
