@@ -1,18 +1,29 @@
 """
-Main interface for signer service type definitions.
+Type annotations for signer service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_signer.type_defs import EncryptionAlgorithmOptionsTypeDef
+    from mypy_boto3_signer.type_defs import AddProfilePermissionResponseTypeDef
 
-    data: EncryptionAlgorithmOptionsTypeDef = {...}
+    data: AddProfilePermissionResponseTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
 from typing import Dict, List
 
+from .literals import (
+    EncryptionAlgorithmType,
+    HashAlgorithmType,
+    ImageFormatType,
+    SigningProfileStatusType,
+    SigningStatusType,
+    ValidityTypeType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
@@ -24,9 +35,22 @@ else:
 
 
 __all__ = (
+    "AddProfilePermissionResponseTypeDef",
+    "DescribeSigningJobResponseTypeDef",
+    "DestinationTypeDef",
     "EncryptionAlgorithmOptionsTypeDef",
+    "GetSigningPlatformResponseTypeDef",
+    "GetSigningProfileResponseTypeDef",
     "HashAlgorithmOptionsTypeDef",
+    "ListProfilePermissionsResponseTypeDef",
+    "ListSigningJobsResponseTypeDef",
+    "ListSigningPlatformsResponseTypeDef",
+    "ListSigningProfilesResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "PaginatorConfigTypeDef",
     "PermissionTypeDef",
+    "PutSigningProfileResponseTypeDef",
+    "RemoveProfilePermissionResponseTypeDef",
     "S3DestinationTypeDef",
     "S3SignedObjectTypeDef",
     "S3SourceTypeDef",
@@ -43,161 +67,16 @@ __all__ = (
     "SigningProfileRevocationRecordTypeDef",
     "SigningProfileTypeDef",
     "SourceTypeDef",
-    "AddProfilePermissionResponseTypeDef",
-    "DescribeSigningJobResponseTypeDef",
-    "DestinationTypeDef",
-    "GetSigningPlatformResponseTypeDef",
-    "GetSigningProfileResponseTypeDef",
-    "ListProfilePermissionsResponseTypeDef",
-    "ListSigningJobsResponseTypeDef",
-    "ListSigningPlatformsResponseTypeDef",
-    "ListSigningProfilesResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "PaginatorConfigTypeDef",
-    "PutSigningProfileResponseTypeDef",
-    "RemoveProfilePermissionResponseTypeDef",
     "StartSigningJobResponseTypeDef",
     "WaiterConfigTypeDef",
 )
 
-EncryptionAlgorithmOptionsTypeDef = TypedDict(
-    "EncryptionAlgorithmOptionsTypeDef",
-    {"allowedValues": List[Literal["RSA", "ECDSA"]], "defaultValue": Literal["RSA", "ECDSA"]},
-)
-
-HashAlgorithmOptionsTypeDef = TypedDict(
-    "HashAlgorithmOptionsTypeDef",
-    {"allowedValues": List[Literal["SHA1", "SHA256"]], "defaultValue": Literal["SHA1", "SHA256"]},
-)
-
-PermissionTypeDef = TypedDict(
-    "PermissionTypeDef",
-    {"action": str, "principal": str, "statementId": str, "profileVersion": str},
-    total=False,
-)
-
-S3DestinationTypeDef = TypedDict(
-    "S3DestinationTypeDef", {"bucketName": str, "prefix": str}, total=False
-)
-
-S3SignedObjectTypeDef = TypedDict(
-    "S3SignedObjectTypeDef", {"bucketName": str, "key": str}, total=False
-)
-
-S3SourceTypeDef = TypedDict("S3SourceTypeDef", {"bucketName": str, "key": str, "version": str})
-
-SignatureValidityPeriodTypeDef = TypedDict(
-    "SignatureValidityPeriodTypeDef",
-    {"value": int, "type": Literal["DAYS", "MONTHS", "YEARS"]},
-    total=False,
-)
-
-SignedObjectTypeDef = TypedDict("SignedObjectTypeDef", {"s3": "S3SignedObjectTypeDef"}, total=False)
-
-SigningConfigurationOverridesTypeDef = TypedDict(
-    "SigningConfigurationOverridesTypeDef",
-    {"encryptionAlgorithm": Literal["RSA", "ECDSA"], "hashAlgorithm": Literal["SHA1", "SHA256"]},
-    total=False,
-)
-
-SigningConfigurationTypeDef = TypedDict(
-    "SigningConfigurationTypeDef",
-    {
-        "encryptionAlgorithmOptions": "EncryptionAlgorithmOptionsTypeDef",
-        "hashAlgorithmOptions": "HashAlgorithmOptionsTypeDef",
-    },
-)
-
-SigningImageFormatTypeDef = TypedDict(
-    "SigningImageFormatTypeDef",
-    {
-        "supportedFormats": List[Literal["JSON", "JSONEmbedded", "JSONDetached"]],
-        "defaultFormat": Literal["JSON", "JSONEmbedded", "JSONDetached"],
-    },
-)
-
-SigningJobRevocationRecordTypeDef = TypedDict(
-    "SigningJobRevocationRecordTypeDef",
-    {"reason": str, "revokedAt": datetime, "revokedBy": str},
-    total=False,
-)
-
-SigningJobTypeDef = TypedDict(
-    "SigningJobTypeDef",
-    {
-        "jobId": str,
-        "source": "SourceTypeDef",
-        "signedObject": "SignedObjectTypeDef",
-        "signingMaterial": "SigningMaterialTypeDef",
-        "createdAt": datetime,
-        "status": Literal["InProgress", "Failed", "Succeeded"],
-        "isRevoked": bool,
-        "profileName": str,
-        "profileVersion": str,
-        "platformId": str,
-        "platformDisplayName": str,
-        "signatureExpiresAt": datetime,
-        "jobOwner": str,
-        "jobInvoker": str,
-    },
-    total=False,
-)
-
-SigningMaterialTypeDef = TypedDict("SigningMaterialTypeDef", {"certificateArn": str})
-
-SigningPlatformOverridesTypeDef = TypedDict(
-    "SigningPlatformOverridesTypeDef",
-    {
-        "signingConfiguration": "SigningConfigurationOverridesTypeDef",
-        "signingImageFormat": Literal["JSON", "JSONEmbedded", "JSONDetached"],
-    },
-    total=False,
-)
-
-SigningPlatformTypeDef = TypedDict(
-    "SigningPlatformTypeDef",
-    {
-        "platformId": str,
-        "displayName": str,
-        "partner": str,
-        "target": str,
-        "category": Literal["AWSIoT"],
-        "signingConfiguration": "SigningConfigurationTypeDef",
-        "signingImageFormat": "SigningImageFormatTypeDef",
-        "maxSizeInMB": int,
-        "revocationSupported": bool,
-    },
-    total=False,
-)
-
-SigningProfileRevocationRecordTypeDef = TypedDict(
-    "SigningProfileRevocationRecordTypeDef",
-    {"revocationEffectiveFrom": datetime, "revokedAt": datetime, "revokedBy": str},
-    total=False,
-)
-
-SigningProfileTypeDef = TypedDict(
-    "SigningProfileTypeDef",
-    {
-        "profileName": str,
-        "profileVersion": str,
-        "profileVersionArn": str,
-        "signingMaterial": "SigningMaterialTypeDef",
-        "signatureValidityPeriod": "SignatureValidityPeriodTypeDef",
-        "platformId": str,
-        "platformDisplayName": str,
-        "signingParameters": Dict[str, str],
-        "status": Literal["Active", "Canceled", "Revoked"],
-        "arn": str,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-SourceTypeDef = TypedDict("SourceTypeDef", {"s3": "S3SourceTypeDef"}, total=False)
-
 AddProfilePermissionResponseTypeDef = TypedDict(
-    "AddProfilePermissionResponseTypeDef", {"revisionId": str}, total=False
+    "AddProfilePermissionResponseTypeDef",
+    {
+        "revisionId": str,
+    },
+    total=False,
 )
 
 DescribeSigningJobResponseTypeDef = TypedDict(
@@ -216,7 +95,7 @@ DescribeSigningJobResponseTypeDef = TypedDict(
         "completedAt": datetime,
         "signatureExpiresAt": datetime,
         "requestedBy": str,
-        "status": Literal["InProgress", "Failed", "Succeeded"],
+        "status": SigningStatusType,
         "statusReason": str,
         "revocationRecord": "SigningJobRevocationRecordTypeDef",
         "signedObject": "SignedObjectTypeDef",
@@ -226,7 +105,21 @@ DescribeSigningJobResponseTypeDef = TypedDict(
     total=False,
 )
 
-DestinationTypeDef = TypedDict("DestinationTypeDef", {"s3": "S3DestinationTypeDef"}, total=False)
+DestinationTypeDef = TypedDict(
+    "DestinationTypeDef",
+    {
+        "s3": "S3DestinationTypeDef",
+    },
+    total=False,
+)
+
+EncryptionAlgorithmOptionsTypeDef = TypedDict(
+    "EncryptionAlgorithmOptionsTypeDef",
+    {
+        "allowedValues": List[EncryptionAlgorithmType],
+        "defaultValue": EncryptionAlgorithmType,
+    },
+)
 
 GetSigningPlatformResponseTypeDef = TypedDict(
     "GetSigningPlatformResponseTypeDef",
@@ -257,7 +150,7 @@ GetSigningProfileResponseTypeDef = TypedDict(
         "signatureValidityPeriod": "SignatureValidityPeriodTypeDef",
         "overrides": "SigningPlatformOverridesTypeDef",
         "signingParameters": Dict[str, str],
-        "status": Literal["Active", "Canceled", "Revoked"],
+        "status": SigningProfileStatusType,
         "statusReason": str,
         "arn": str,
         "tags": Dict[str, str],
@@ -265,6 +158,14 @@ GetSigningProfileResponseTypeDef = TypedDict(
     total=False,
 )
 
+HashAlgorithmOptionsTypeDef = TypedDict(
+    "HashAlgorithmOptionsTypeDef",
+    {
+        "allowedValues": List[HashAlgorithmType],
+        "defaultValue": HashAlgorithmType,
+    },
+)
+
 ListProfilePermissionsResponseTypeDef = TypedDict(
     "ListProfilePermissionsResponseTypeDef",
     {
@@ -278,44 +179,260 @@ ListProfilePermissionsResponseTypeDef = TypedDict(
 
 ListSigningJobsResponseTypeDef = TypedDict(
     "ListSigningJobsResponseTypeDef",
-    {"jobs": List["SigningJobTypeDef"], "nextToken": str},
+    {
+        "jobs": List["SigningJobTypeDef"],
+        "nextToken": str,
+    },
     total=False,
 )
 
 ListSigningPlatformsResponseTypeDef = TypedDict(
     "ListSigningPlatformsResponseTypeDef",
-    {"platforms": List["SigningPlatformTypeDef"], "nextToken": str},
+    {
+        "platforms": List["SigningPlatformTypeDef"],
+        "nextToken": str,
+    },
     total=False,
 )
 
 ListSigningProfilesResponseTypeDef = TypedDict(
     "ListSigningProfilesResponseTypeDef",
-    {"profiles": List["SigningProfileTypeDef"], "nextToken": str},
+    {
+        "profiles": List["SigningProfileTypeDef"],
+        "nextToken": str,
+    },
     total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+PermissionTypeDef = TypedDict(
+    "PermissionTypeDef",
+    {
+        "action": str,
+        "principal": str,
+        "statementId": str,
+        "profileVersion": str,
+    },
+    total=False,
 )
 
 PutSigningProfileResponseTypeDef = TypedDict(
     "PutSigningProfileResponseTypeDef",
-    {"arn": str, "profileVersion": str, "profileVersionArn": str},
+    {
+        "arn": str,
+        "profileVersion": str,
+        "profileVersionArn": str,
+    },
     total=False,
 )
 
 RemoveProfilePermissionResponseTypeDef = TypedDict(
-    "RemoveProfilePermissionResponseTypeDef", {"revisionId": str}, total=False
+    "RemoveProfilePermissionResponseTypeDef",
+    {
+        "revisionId": str,
+    },
+    total=False,
+)
+
+S3DestinationTypeDef = TypedDict(
+    "S3DestinationTypeDef",
+    {
+        "bucketName": str,
+        "prefix": str,
+    },
+    total=False,
+)
+
+S3SignedObjectTypeDef = TypedDict(
+    "S3SignedObjectTypeDef",
+    {
+        "bucketName": str,
+        "key": str,
+    },
+    total=False,
+)
+
+S3SourceTypeDef = TypedDict(
+    "S3SourceTypeDef",
+    {
+        "bucketName": str,
+        "key": str,
+        "version": str,
+    },
+)
+
+SignatureValidityPeriodTypeDef = TypedDict(
+    "SignatureValidityPeriodTypeDef",
+    {
+        "value": int,
+        "type": ValidityTypeType,
+    },
+    total=False,
+)
+
+SignedObjectTypeDef = TypedDict(
+    "SignedObjectTypeDef",
+    {
+        "s3": "S3SignedObjectTypeDef",
+    },
+    total=False,
+)
+
+SigningConfigurationOverridesTypeDef = TypedDict(
+    "SigningConfigurationOverridesTypeDef",
+    {
+        "encryptionAlgorithm": EncryptionAlgorithmType,
+        "hashAlgorithm": HashAlgorithmType,
+    },
+    total=False,
+)
+
+SigningConfigurationTypeDef = TypedDict(
+    "SigningConfigurationTypeDef",
+    {
+        "encryptionAlgorithmOptions": "EncryptionAlgorithmOptionsTypeDef",
+        "hashAlgorithmOptions": "HashAlgorithmOptionsTypeDef",
+    },
+)
+
+SigningImageFormatTypeDef = TypedDict(
+    "SigningImageFormatTypeDef",
+    {
+        "supportedFormats": List[ImageFormatType],
+        "defaultFormat": ImageFormatType,
+    },
+)
+
+SigningJobRevocationRecordTypeDef = TypedDict(
+    "SigningJobRevocationRecordTypeDef",
+    {
+        "reason": str,
+        "revokedAt": datetime,
+        "revokedBy": str,
+    },
+    total=False,
+)
+
+SigningJobTypeDef = TypedDict(
+    "SigningJobTypeDef",
+    {
+        "jobId": str,
+        "source": "SourceTypeDef",
+        "signedObject": "SignedObjectTypeDef",
+        "signingMaterial": "SigningMaterialTypeDef",
+        "createdAt": datetime,
+        "status": SigningStatusType,
+        "isRevoked": bool,
+        "profileName": str,
+        "profileVersion": str,
+        "platformId": str,
+        "platformDisplayName": str,
+        "signatureExpiresAt": datetime,
+        "jobOwner": str,
+        "jobInvoker": str,
+    },
+    total=False,
+)
+
+SigningMaterialTypeDef = TypedDict(
+    "SigningMaterialTypeDef",
+    {
+        "certificateArn": str,
+    },
+)
+
+SigningPlatformOverridesTypeDef = TypedDict(
+    "SigningPlatformOverridesTypeDef",
+    {
+        "signingConfiguration": "SigningConfigurationOverridesTypeDef",
+        "signingImageFormat": ImageFormatType,
+    },
+    total=False,
+)
+
+SigningPlatformTypeDef = TypedDict(
+    "SigningPlatformTypeDef",
+    {
+        "platformId": str,
+        "displayName": str,
+        "partner": str,
+        "target": str,
+        "category": Literal["AWSIoT"],
+        "signingConfiguration": "SigningConfigurationTypeDef",
+        "signingImageFormat": "SigningImageFormatTypeDef",
+        "maxSizeInMB": int,
+        "revocationSupported": bool,
+    },
+    total=False,
+)
+
+SigningProfileRevocationRecordTypeDef = TypedDict(
+    "SigningProfileRevocationRecordTypeDef",
+    {
+        "revocationEffectiveFrom": datetime,
+        "revokedAt": datetime,
+        "revokedBy": str,
+    },
+    total=False,
+)
+
+SigningProfileTypeDef = TypedDict(
+    "SigningProfileTypeDef",
+    {
+        "profileName": str,
+        "profileVersion": str,
+        "profileVersionArn": str,
+        "signingMaterial": "SigningMaterialTypeDef",
+        "signatureValidityPeriod": "SignatureValidityPeriodTypeDef",
+        "platformId": str,
+        "platformDisplayName": str,
+        "signingParameters": Dict[str, str],
+        "status": SigningProfileStatusType,
+        "arn": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+SourceTypeDef = TypedDict(
+    "SourceTypeDef",
+    {
+        "s3": "S3SourceTypeDef",
+    },
+    total=False,
 )
 
 StartSigningJobResponseTypeDef = TypedDict(
-    "StartSigningJobResponseTypeDef", {"jobId": str, "jobOwner": str}, total=False
+    "StartSigningJobResponseTypeDef",
+    {
+        "jobId": str,
+        "jobOwner": str,
+    },
+    total=False,
 )
 
 WaiterConfigTypeDef = TypedDict(
-    "WaiterConfigTypeDef", {"Delay": int, "MaxAttempts": int}, total=False
+    "WaiterConfigTypeDef",
+    {
+        "Delay": int,
+        "MaxAttempts": int,
+    },
+    total=False,
 )
